#
# spec file for package ghc-unix-compat
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name unix-compat
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.7.4
Release:        1.1
Summary:        Portable POSIX-compatibility layer
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-unix-devel
BuildRequires:  ghc-unix-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-HUnit-prof
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-directory-prof
BuildRequires:  ghc-extra-devel
BuildRequires:  ghc-extra-prof
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-hspec-prof
BuildRequires:  ghc-monad-parallel-devel
BuildRequires:  ghc-monad-parallel-prof
BuildRequires:  ghc-temporary-devel
BuildRequires:  ghc-temporary-prof
%endif

%description
This package provides portable implementations of parts of the unix package.
This package re-exports the unix package when available. When it isn't
available, portable implementations are used.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Thu Mar 27 2025 Peter Simons <psimons@suse.com>
- Update unix-compat to version 0.7.4.
  [#]# Version 0.7.4 (2025-03-27)
  - Add `wasm32-wasi` support
    ([PR #16](https://github.com/haskell-pkg-janitors/unix-compat/pull/16)).
  - Tested with GHC 8.0 - 9.12.
* Fri Jan 17 2025 Peter Simons <psimons@suse.com>
- Update unix-compat to version 0.7.3 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Fri Oct 11 2024 Peter Simons <psimons@suse.com>
- Update unix-compat to version 0.7.3.
  [#]# Version 0.7.3 (2024-10-11)
  - Fix `sysmacros.h` include for GNU/Hurd
    ([PR #12](https://github.com/haskell-pkg-janitors/unix-compat/pull/12)).
  - Tested with GHC 8.0 - 9.10.
* Tue Jun 25 2024 Peter Simons <psimons@suse.com>
- Update unix-compat to version 0.7.2.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/unix-compat-0.7.2/src/CHANGELOG.md
* Wed Dec  6 2023 Peter Simons <psimons@suse.com>
- Update unix-compat to version 0.7.1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/unix-compat-0.7.1/src/CHANGELOG.md
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Update unix-compat to version 0.7.
  [#]# Version 0.7 (2023-03-15)
  - Remote `System.PosixCompat.User` module
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Thu Sep 29 2022 Peter Simons <psimons@suse.com>
- Update unix-compat to version 0.6 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun May 22 2022 Peter Simons <psimons@suse.com>
- Update unix-compat to version 0.6.
  Upstream added a new change log file in this release. With no
  previous version to compare against, the automatic updater cannot
  reliable determine the relevante entries for this release.
* Thu Mar 24 2022 Peter Simons <psimons@suse.com>
- Update unix-compat to version 0.5.4 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Jan 11 2022 Peter Simons <psimons@suse.com>
- Update unix-compat to version 0.5.4.
  Upstream does not provide a change log file.
* Mon Nov 15 2021 psimons@suse.com
- Update unix-compat to version 0.5.3 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun Jan 24 2021 psimons@suse.com
- Update unix-compat to version 0.5.3.
  Upstream does not provide a change log file.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Mon Aug 31 2020 psimons@suse.com
- Update unix-compat to version 0.5.2 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Thu May  7 2020 Peter Simons <psimons@suse.com>
- Update Cabal file to get more accurate dependency information.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Sat Aug 10 2019 psimons@suse.com
- Update unix-compat to version 0.5.2.
  Upstream does not provide a change log file.
* Tue Jun 11 2019 Peter Simons <psimons@suse.com>
- Update Cabal file for more accurate build dependencies.
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Thu Aug 30 2018 psimons@suse.com
- Update unix-compat to version 0.5.1.
  Upstream does not provide a change log file.
* Tue Jul 31 2018 psimons@suse.com
- Revise Cabal build instructions to support 'unix' version 2.8.x.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update unix-compat to version 0.5.0.1.
  Upstream does not provide a changelog.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Mon Jul 31 2017 psimons@suse.com
- Update to version 0.4.3.1 revision 2.
* Mon Jan 16 2017 psimons@suse.com
- Update to version 0.4.3.1 revision 1 with cabal2obs.
* Fri Dec 16 2016 psimons@suse.com
- Update to version 0.4.3.1 with cabal2obs.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 0.4.2.0 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.4.1.4 revision 2 with cabal2obs.
* Thu Apr 23 2015 mimi.vx@gmail.com
- initial commit
